/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.iggy.message;

import java.math.BigInteger;

public record MessageHeader(
        BigInteger checksum,
        MessageId id,
        BigInteger offset,
        BigInteger timestamp,
        BigInteger originTimestamp,
        Long userHeadersLength,
        Long payloadLength,
        BigInteger reserved) {
    public static final int SIZE = 8 + 16 + 8 + 8 + 8 + 4 + 4 + 8;
}
